@@ -69,6 +69,9 @@ class Handler:
             # Write the contents of the buffer to a file
             file_handle.write(buffer.get_text(buffer.get_start_iter(), buffer.get_end_iter(), include_hidden_chars=False))
 
+        # Let user know change was saved
+        Notify.Notification.new("Changes Saved").show()
+
 ################################################################################
 ############################### Drawing App Window #############################
 ################################################################################
